JBossWS SVN: r2465 - trunk/build/ant-import.
by jbossws-commits@lists.jboss.org
Author: jason.greene(a)jboss.com
Date: 2007-02-23 16:54:10 -0500 (Fri, 23 Feb 2007)
New Revision: 2465
Modified:
trunk/build/ant-import/build-hudson.xml
trunk/build/ant-import/build-release.xml
Log:
merge
Modified: trunk/build/ant-import/build-hudson.xml
===================================================================
--- trunk/build/ant-import/build-hudson.xml 2007-02-23 21:51:05 UTC (rev 2464)
+++ trunk/build/ant-import/build-hudson.xml 2007-02-23 21:54:10 UTC (rev 2465)
@@ -119,7 +119,7 @@
<echo/>
<echo message="*************************************"/>
- <echo message="* Hudson started sucessfuly *"/>
+ <echo message="* Hudson started successfully *"/>
<echo message="* http://localhost:${hudson.port}/hudson *"/>
<echo message="*************************************"/>
<echo/>
Modified: trunk/build/ant-import/build-release.xml
===================================================================
--- trunk/build/ant-import/build-release.xml 2007-02-23 21:51:05 UTC (rev 2464)
+++ trunk/build/ant-import/build-release.xml 2007-02-23 21:54:10 UTC (rev 2465)
@@ -27,12 +27,13 @@
<echo message="* 3) Update portal-content/counter.xml"/>
<echo message="* 4) Update news in portal-content/freezone/projectDescription.xml"/>
<echo message="* 5) Verify release notes and install instructions"/>
- <echo message="* 6) Commit the portal-content"/>
- <echo message="* 7) Commit the repository jars"/>
- <echo message="* 8) Write a sticky post on the user forum"/>
- <echo message="* 9) Release the jbossws-${version.id} version in JIRA"/>
- <echo message="* 10) Post a message to jbossws-announce(a)lists.jboss.org"/>
- <echo message="* 11) Post a message to thecore(a)jboss.org"/>
+ <echo message="* 6) Publish the interop endpoints (ant -f jboss-tests/build.xml publish-interop-endpoints)"/>
+ <echo message="* 7) Commit the portal-content"/>
+ <echo message="* 8) Commit the repository jars"/>
+ <echo message="* 9) Write a sticky post on the user forum"/>
+ <echo message="* 10) Release the jbossws-${version.id} version in JIRA"/>
+ <echo message="* 11) Post a message to jbossws-announce(a)lists.jboss.org"/>
+ <echo message="* 12) Post a message to thecore(a)jboss.org"/>
<echo message="*"/>
<echo message="*********************************************"/>
</target>
@@ -158,12 +159,12 @@
<fileset dir="${etc.dir}">
<include name="wstools.bat"/>
<include name="wstools.sh"/>
- <include name="wsrunclient.sh"/>
- <include name="wsrunclient.bat"/>
<include name="wsprovide.bat"/>
<include name="wsprovide.sh"/>
<include name="wsconsume.bat"/>
<include name="wsconsume.sh"/>
+ <include name="wsrunclient.bat"/>
+ <include name="wsrunclient.sh"/>
</fileset>
</copy>
18 years
JBossWS SVN: r2464 - trunk/build/etc.
by jbossws-commits@lists.jboss.org
Author: jason.greene(a)jboss.com
Date: 2007-02-23 16:51:05 -0500 (Fri, 23 Feb 2007)
New Revision: 2464
Modified:
trunk/build/etc/wsconsume.bat
trunk/build/etc/wsconsume.sh
trunk/build/etc/wsprovide.bat
trunk/build/etc/wsrunclient.bat
trunk/build/etc/wsrunclient.sh
Log:
merge classpath changes that add compatibility to 4.2
Modified: trunk/build/etc/wsconsume.bat
===================================================================
--- trunk/build/etc/wsconsume.bat 2007-02-23 21:31:39 UTC (rev 2463)
+++ trunk/build/etc/wsconsume.bat 2007-02-23 21:51:05 UTC (rev 2464)
@@ -30,15 +30,21 @@
set JBOSS_ENDORSED_DIRS=%JBOSS_HOME%\lib\endorsed
rem Setup the wstools classpath
+set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JAVA_HOME%/lib/tools.jar
set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/jboss-xml-binding.jar
+set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/wstx.jar
set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/activation.jar
set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/javassist.jar
set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/getopt.jar
set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/jaxb-api.jar
+set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/stax-api.jar
set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/jaxb-impl.jar
set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/jaxb-xjc.jar
-set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/jbossws-wsimport-impl.jar
+set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/jbossws-wsconsume-impl.jar
set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/jbossall-client.jar
+set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/jboss-saaj.jar
+set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/jboss-jaxrpc.jar
+set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/jboss-jaxws.jar
set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/jbossws-client.jar
set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/log4j.jar
set WSCONSUME_CLASSPATH=%WSCONSUME_CLASSPATH%;%JBOSS_HOME%/client/mail.jar
Modified: trunk/build/etc/wsconsume.sh
===================================================================
--- trunk/build/etc/wsconsume.sh 2007-02-23 21:31:39 UTC (rev 2463)
+++ trunk/build/etc/wsconsume.sh 2007-02-23 21:51:05 UTC (rev 2464)
@@ -55,6 +55,7 @@
WSCONSUME_CLASSPATH="$WSCONSUME_CLASSPATH:$JBOSS_HOME/client/getopt.jar"
WSCONSUME_CLASSPATH="$WSCONSUME_CLASSPATH:$JBOSS_HOME/client/javassist.jar"
WSCONSUME_CLASSPATH="$WSCONSUME_CLASSPATH:$JBOSS_HOME/client/jaxb-api.jar"
+WSCONSUME_CLASSPATH="$WSCONSUME_CLASSPATH:$JBOSS_HOME/client/stax-api.jar"
WSCONSUME_CLASSPATH="$WSCONSUME_CLASSPATH:$JBOSS_HOME/client/jaxb-impl.jar"
WSCONSUME_CLASSPATH="$WSCONSUME_CLASSPATH:$JBOSS_HOME/client/jaxb-xjc.jar"
WSCONSUME_CLASSPATH="$WSCONSUME_CLASSPATH:$JBOSS_HOME/client/jbossall-client.jar"
Modified: trunk/build/etc/wsprovide.bat
===================================================================
--- trunk/build/etc/wsprovide.bat 2007-02-23 21:31:39 UTC (rev 2463)
+++ trunk/build/etc/wsprovide.bat 2007-02-23 21:51:05 UTC (rev 2464)
@@ -38,6 +38,9 @@
set WSPROVIDE_CLASSPATH=%WSPROVIDE_CLASSPATH%;%JBOSS_HOME%/client/jaxb-impl.jar
set WSPROVIDE_CLASSPATH=%WSPROVIDE_CLASSPATH%;%JBOSS_HOME%/client/jbossall-client.jar
set WSPROVIDE_CLASSPATH=%WSPROVIDE_CLASSPATH%;%JBOSS_HOME%/client/jbossws-client.jar
+set WSPROVIDE_CLASSPATH=%WSPROVIDE_CLASSPATH%;%JBOSS_HOME%/client/jboss-jaxws.jar
+set WSPROVIDE_CLASSPATH=%WSPROVIDE_CLASSPATH%;%JBOSS_HOME%/client/jboss-jaxrpc.jar
+set WSPROVIDE_CLASSPATH=%WSPROVIDE_CLASSPATH%;%JBOSS_HOME%/client/jboss-saaj.jar
set WSPROVIDE_CLASSPATH=%WSPROVIDE_CLASSPATH%;%JBOSS_HOME%/client/log4j.jar
set WSPROVIDE_CLASSPATH=%WSPROVIDE_CLASSPATH%;%JBOSS_HOME%/client/mail.jar
Modified: trunk/build/etc/wsrunclient.bat
===================================================================
--- trunk/build/etc/wsrunclient.bat 2007-02-23 21:31:39 UTC (rev 2463)
+++ trunk/build/etc/wsrunclient.bat 2007-02-23 21:51:05 UTC (rev 2464)
@@ -47,6 +47,9 @@
set WSRUNCLIENT_CLASSPATH=%WSRUNCLIENT_CLASSPATH%;%JBOSS_HOME%/client/jaxb-api.jar
set WSRUNCLIENT_CLASSPATH=%WSRUNCLIENT_CLASSPATH%;%JBOSS_HOME%/client/jaxb-impl.jar
set WSRUNCLIENT_CLASSPATH=%WSRUNCLIENT_CLASSPATH%;%JBOSS_HOME%/client/jbossall-client.jar
+set WSRUNCLIENT_CLASSPATH=%WSRUNCLIENT_CLASSPATH%;%JBOSS_HOME%/client/stax-api.jar
+set WSRUNCLIENT_CLASSPATH=%WSRUNCLIENT_CLASSPATH%;%JBOSS_HOME%/client/wstx.jar
+set WSRUNCLIENT_CLASSPATH=%WSRUNCLIENT_CLASSPATH%;%JBOSS_HOME%/client/jboss-j2ee.jar
set WSRUNCLIENT_CLASSPATH=%WSRUNCLIENT_CLASSPATH%;%JBOSS_HOME%/client/jboss-saaj.jar
set WSRUNCLIENT_CLASSPATH=%WSRUNCLIENT_CLASSPATH%;%JBOSS_HOME%/client/jboss-jaxws.jar
set WSRUNCLIENT_CLASSPATH=%WSRUNCLIENT_CLASSPATH%;%JBOSS_HOME%/client/jboss-jaxrpc.jar
Modified: trunk/build/etc/wsrunclient.sh
===================================================================
--- trunk/build/etc/wsrunclient.sh 2007-02-23 21:31:39 UTC (rev 2463)
+++ trunk/build/etc/wsrunclient.sh 2007-02-23 21:51:05 UTC (rev 2464)
@@ -65,12 +65,14 @@
WSRUNCLIENT_CLASSPATH="$WSRUNCLIENT_CLASSPATH:$JBOSS_HOME/client/jaxb-xjc.jar"
WSRUNCLIENT_CLASSPATH="$WSRUNCLIENT_CLASSPATH:$JBOSS_HOME/client/jbossall-client.jar"
WSRUNCLIENT_CLASSPATH="$WSRUNCLIENT_CLASSPATH:$JBOSS_HOME/client/jboss-j2ee.jar"
+WSRUNCLIENT_CLASSPATH="$WSRUNCLIENT_CLASSPATH:$JBOSS_HOME/client/jboss-ejb3x.jar"
WSRUNCLIENT_CLASSPATH="$WSRUNCLIENT_CLASSPATH:$JBOSS_HOME/client/jbossws-client.jar"
WSRUNCLIENT_CLASSPATH="$WSRUNCLIENT_CLASSPATH:$JBOSS_HOME/client/jboss-jaxws.jar"
WSRUNCLIENT_CLASSPATH="$WSRUNCLIENT_CLASSPATH:$JBOSS_HOME/client/jboss-jaxrpc.jar"
WSRUNCLIENT_CLASSPATH="$WSRUNCLIENT_CLASSPATH:$JBOSS_HOME/client/jboss-saaj.jar"
WSRUNCLIENT_CLASSPATH="$WSRUNCLIENT_CLASSPATH:$JBOSS_HOME/client/log4j.jar"
WSRUNCLIENT_CLASSPATH="$WSRUNCLIENT_CLASSPATH:$JBOSS_HOME/client/mail.jar"
+WSRUNCLIENT_CLASSPATH="$WSRUNCLIENT_CLASSPATH:$JBOSS_HOME/client/stax-api.jar"
WSRUNCLIENT_CLASSPATH="$WSRUNCLIENT_CLASSPATH:$JBOSS_HOME/client/wstx.jar"
while [ $# -ge 1 ]; do
18 years
JBossWS SVN: r2463 - branches/jbossws-1.2.0/build/etc.
by jbossws-commits@lists.jboss.org
Author: thomas.diesler(a)jboss.com
Date: 2007-02-23 16:31:39 -0500 (Fri, 23 Feb 2007)
New Revision: 2463
Modified:
branches/jbossws-1.2.0/build/etc/jbossws-component-info.xml
branches/jbossws-1.2.0/build/etc/jbossws-component-info14.xml
Log:
Add a dependency on bpel
Modified: branches/jbossws-1.2.0/build/etc/jbossws-component-info.xml
===================================================================
--- branches/jbossws-1.2.0/build/etc/jbossws-component-info.xml 2007-02-23 21:14:41 UTC (rev 2462)
+++ branches/jbossws-1.2.0/build/etc/jbossws-component-info.xml 2007-02-23 21:31:39 UTC (rev 2463)
@@ -22,6 +22,9 @@
<import componentref="javassist">
<compatible version="@javassist@"/>
</import>
+ <import componentref="jbpm/bpel">
+ <compatible version="@jbpm-bpel@"/>
+ </import>
<import componentref="jboss/jbossxb">
<compatible version="@jboss-jbossxb@"/>
</import>
Modified: branches/jbossws-1.2.0/build/etc/jbossws-component-info14.xml
===================================================================
--- branches/jbossws-1.2.0/build/etc/jbossws-component-info14.xml 2007-02-23 21:14:41 UTC (rev 2462)
+++ branches/jbossws-1.2.0/build/etc/jbossws-component-info14.xml 2007-02-23 21:31:39 UTC (rev 2463)
@@ -19,6 +19,9 @@
<import componentref="javassist">
<compatible version="@javassist@"/>
</import>
+ <import componentref="jbpm/bpel">
+ <compatible version="@jbpm-bpel@"/>
+ </import>
<import componentref="jboss/jbossretro">
<compatible version="@jboss-jbossretro@"/>
</import>
18 years
JBossWS SVN: r2462 - trunk/integration-jboss50.
by jbossws-commits@lists.jboss.org
Author: jason.greene(a)jboss.com
Date: 2007-02-23 16:14:41 -0500 (Fri, 23 Feb 2007)
New Revision: 2462
Modified:
trunk/integration-jboss50/.classpath
trunk/integration-jboss50/build.xml
Log:
merge
Modified: trunk/integration-jboss50/.classpath
===================================================================
--- trunk/integration-jboss50/.classpath 2007-02-23 20:33:41 UTC (rev 2461)
+++ trunk/integration-jboss50/.classpath 2007-02-23 21:14:41 UTC (rev 2462)
@@ -30,6 +30,5 @@
<classpathentry kind="lib" path="/build/thirdparty/jbosssx-client.jar" sourcepath="/build/thirdparty/jbosssx-src.zip"/>
<classpathentry kind="con" path="org.eclipse.jdt.USER_LIBRARY/jboss-5.0.x"/>
<classpathentry kind="lib" path="/build/thirdparty/jboss-common.jar" sourcepath="/build/thirdparty/jboss-common-sources.jar"/>
- <classpathentry combineaccessrules="false" kind="src" path="/integration-jboss42"/>
<classpathentry kind="output" path="output-eclipse"/>
</classpath>
Modified: trunk/integration-jboss50/build.xml
===================================================================
--- trunk/integration-jboss50/build.xml 2007-02-23 20:33:41 UTC (rev 2461)
+++ trunk/integration-jboss50/build.xml 2007-02-23 21:14:41 UTC (rev 2462)
@@ -140,6 +140,12 @@
<!-- Deploy jbossws to jboss50 -->
<target name="deploy-jboss50" depends="jboss50-jars" description="Deploy jbossws">
+ <copy todir="${jboss50.home}/bin" overwrite="true">
+ <fileset dir="${etc.dir}">
+ <include name="*.bat"/>
+ <include name="*.sh"/>
+ </fileset>
+ </copy>
<copy todir="${jboss50.home}/client" overwrite="true">
<fileset dir="${core.output.lib.dir}">
<include name="jboss-jaxrpc.jar"/>
@@ -200,4 +206,4 @@
<target name="all" description="Create a distribution zip file" depends="main">
</target>
-</project>
\ No newline at end of file
+</project>
18 years
JBossWS SVN: r2461 - in trunk/integration-jboss40/src/main: java/org and 7 other directories.
by jbossws-commits@lists.jboss.org
Author: jason.greene(a)jboss.com
Date: 2007-02-23 15:33:41 -0500 (Fri, 23 Feb 2007)
New Revision: 2461
Added:
trunk/integration-jboss40/src/main/java/org/
trunk/integration-jboss40/src/main/java/org/jboss/
trunk/integration-jboss40/src/main/java/org/jboss/ws/
trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/
trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/
trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/ServiceRefMetaDataAdaptor.java
trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployer.java
trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployerMBean.java
trunk/integration-jboss40/src/main/resources/jbossws.sar/
trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/
trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml
trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service.xml
Removed:
trunk/integration-jboss40/src/main/java/org/jboss/
trunk/integration-jboss40/src/main/java/org/jboss/ws/
trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/
trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/
trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/ServiceRefMetaDataAdaptor.java
trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployer.java
trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployerMBean.java
trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/
trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml
trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service.xml
Log:
merge missing jboss40 integration
Copied: trunk/integration-jboss40/src/main/java/org (from rev 2460, branches/jbossws-1.2.0/integration-jboss40/src/main/java/org)
Copied: trunk/integration-jboss40/src/main/java/org/jboss (from rev 2460, branches/jbossws-1.2.0/integration-jboss40/src/main/java/org/jboss)
Copied: trunk/integration-jboss40/src/main/java/org/jboss/ws (from rev 2460, branches/jbossws-1.2.0/integration-jboss40/src/main/java/org/jboss/ws)
Copied: trunk/integration-jboss40/src/main/java/org/jboss/ws/integration (from rev 2460, branches/jbossws-1.2.0/integration-jboss40/src/main/java/org/jboss/ws/integration)
Copied: trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40 (from rev 2460, branches/jbossws-1.2.0/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40)
Deleted: trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/ServiceRefMetaDataAdaptor.java
===================================================================
--- branches/jbossws-1.2.0/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/ServiceRefMetaDataAdaptor.java 2007-02-23 20:32:50 UTC (rev 2460)
+++ trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/ServiceRefMetaDataAdaptor.java 2007-02-23 20:33:41 UTC (rev 2461)
@@ -1,107 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source
- * Copyright 2005, JBoss Inc., and individual contributors as indicated
- * by the @authors tag. See the copyright.txt in the distribution for a
- * full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.ws.integration.jboss40;
-
-// $Id$
-
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.LinkedHashMap;
-
-import javax.xml.namespace.QName;
-
-import org.jboss.webservice.metadata.serviceref.HandlerMetaData;
-import org.jboss.webservice.metadata.serviceref.InitParamMetaData;
-import org.jboss.webservice.metadata.serviceref.PortComponentRefMetaData;
-import org.jboss.webservice.metadata.serviceref.ServiceRefMetaData;
-import org.jboss.ws.core.server.UnifiedDeploymentInfo;
-import org.jboss.ws.metadata.j2ee.UnifiedHandlerMetaData;
-import org.jboss.ws.metadata.j2ee.UnifiedPortComponentRefMetaData;
-import org.jboss.ws.metadata.j2ee.UnifiedServiceRefMetaData;
-import org.jboss.ws.metadata.umdm.HandlerMetaData.HandlerInitParam;
-
-/**
- * Build container independent service ref meta data
- *
- * @author Thomas.Diesler(a)jboss.org
- * @since 05-May-2006
- */
-public class ServiceRefMetaDataAdaptor
-{
- public static UnifiedServiceRefMetaData buildUnifiedServiceRefMetaData(UnifiedDeploymentInfo udi, ServiceRefMetaData srmd) throws IOException
- {
- UnifiedServiceRefMetaData usrmd = new UnifiedServiceRefMetaData();
- usrmd.setServiceRefName(srmd.getServiceRefName());
- usrmd.setServiceInterface(srmd.getServiceInterface());
- usrmd.setWsdlLocation(srmd.getWsdlURL());
- usrmd.setMappingLocation(udi.getMetaDataFileURL(srmd.getJaxrpcMappingFile()));
- usrmd.setServiceQName(srmd.getServiceQName());
-
- LinkedHashMap<String, UnifiedPortComponentRefMetaData> pcrefs = new LinkedHashMap<String, UnifiedPortComponentRefMetaData>();
- for (PortComponentRefMetaData pcmd : srmd.getPortComponentRefs())
- {
- UnifiedPortComponentRefMetaData upcmd = new UnifiedPortComponentRefMetaData();
- upcmd.setServiceEndpointInterface(pcmd.getServiceEndpointInterface());
- upcmd.setPortComponentLink(pcmd.getPortComponentLink());
- upcmd.setCallProperties(pcmd.getCallProperties());
- pcrefs.put(pcmd.getServiceEndpointInterface(), upcmd);
- }
- usrmd.setPortComponentRefs(pcrefs);
-
- ArrayList<UnifiedHandlerMetaData> handlers = new ArrayList<UnifiedHandlerMetaData>();
- for (HandlerMetaData hmd : srmd.getHandlers())
- {
- UnifiedHandlerMetaData uhmd = new UnifiedHandlerMetaData(null);
- uhmd.setHandlerName(hmd.getHandlerName());
- uhmd.setHandlerClass(hmd.getHandlerClass());
-
- for(String portname : hmd.getPortNames())
- {
- uhmd.addPortName(portname);
- }
- for (InitParamMetaData ipmd : hmd.getInitParams())
- {
- HandlerInitParam ip = new HandlerInitParam();
- ip.setParamName(ipmd.getParamName());
- ip.setParamValue(ipmd.getParamValue());
- uhmd.addInitParam(ip);
- }
- for (QName soapHeader : hmd.getSoapHeaders())
- {
- uhmd.addSoapHeader(soapHeader);
- }
- for (String soapRole : hmd.getSoapRoles())
- {
- uhmd.addSoapRole(soapRole);
- }
- handlers.add(uhmd);
- }
- usrmd.setHandlers(handlers);
-
- usrmd.setConfigName(srmd.getConfigName());
- usrmd.setConfigFile(srmd.getConfigFile());
- usrmd.setWsdlOverride(srmd.getWsdlOverride());
- usrmd.setCallProperties(srmd.getCallProperties());
-
- return usrmd;
- }
-}
Copied: trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/ServiceRefMetaDataAdaptor.java (from rev 2460, branches/jbossws-1.2.0/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/ServiceRefMetaDataAdaptor.java)
===================================================================
--- trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/ServiceRefMetaDataAdaptor.java (rev 0)
+++ trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/ServiceRefMetaDataAdaptor.java 2007-02-23 20:33:41 UTC (rev 2461)
@@ -0,0 +1,107 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2005, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.ws.integration.jboss40;
+
+// $Id$
+
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.LinkedHashMap;
+
+import javax.xml.namespace.QName;
+
+import org.jboss.webservice.metadata.serviceref.HandlerMetaData;
+import org.jboss.webservice.metadata.serviceref.InitParamMetaData;
+import org.jboss.webservice.metadata.serviceref.PortComponentRefMetaData;
+import org.jboss.webservice.metadata.serviceref.ServiceRefMetaData;
+import org.jboss.ws.core.server.UnifiedDeploymentInfo;
+import org.jboss.ws.metadata.j2ee.UnifiedHandlerMetaData;
+import org.jboss.ws.metadata.j2ee.UnifiedPortComponentRefMetaData;
+import org.jboss.ws.metadata.j2ee.UnifiedServiceRefMetaData;
+import org.jboss.ws.metadata.umdm.HandlerMetaData.HandlerInitParam;
+
+/**
+ * Build container independent service ref meta data
+ *
+ * @author Thomas.Diesler(a)jboss.org
+ * @since 05-May-2006
+ */
+public class ServiceRefMetaDataAdaptor
+{
+ public static UnifiedServiceRefMetaData buildUnifiedServiceRefMetaData(UnifiedDeploymentInfo udi, ServiceRefMetaData srmd) throws IOException
+ {
+ UnifiedServiceRefMetaData usrmd = new UnifiedServiceRefMetaData();
+ usrmd.setServiceRefName(srmd.getServiceRefName());
+ usrmd.setServiceInterface(srmd.getServiceInterface());
+ usrmd.setWsdlLocation(srmd.getWsdlURL());
+ usrmd.setMappingLocation(udi.getMetaDataFileURL(srmd.getJaxrpcMappingFile()));
+ usrmd.setServiceQName(srmd.getServiceQName());
+
+ LinkedHashMap<String, UnifiedPortComponentRefMetaData> pcrefs = new LinkedHashMap<String, UnifiedPortComponentRefMetaData>();
+ for (PortComponentRefMetaData pcmd : srmd.getPortComponentRefs())
+ {
+ UnifiedPortComponentRefMetaData upcmd = new UnifiedPortComponentRefMetaData();
+ upcmd.setServiceEndpointInterface(pcmd.getServiceEndpointInterface());
+ upcmd.setPortComponentLink(pcmd.getPortComponentLink());
+ upcmd.setCallProperties(pcmd.getCallProperties());
+ pcrefs.put(pcmd.getServiceEndpointInterface(), upcmd);
+ }
+ usrmd.setPortComponentRefs(pcrefs);
+
+ ArrayList<UnifiedHandlerMetaData> handlers = new ArrayList<UnifiedHandlerMetaData>();
+ for (HandlerMetaData hmd : srmd.getHandlers())
+ {
+ UnifiedHandlerMetaData uhmd = new UnifiedHandlerMetaData(null);
+ uhmd.setHandlerName(hmd.getHandlerName());
+ uhmd.setHandlerClass(hmd.getHandlerClass());
+
+ for(String portname : hmd.getPortNames())
+ {
+ uhmd.addPortName(portname);
+ }
+ for (InitParamMetaData ipmd : hmd.getInitParams())
+ {
+ HandlerInitParam ip = new HandlerInitParam();
+ ip.setParamName(ipmd.getParamName());
+ ip.setParamValue(ipmd.getParamValue());
+ uhmd.addInitParam(ip);
+ }
+ for (QName soapHeader : hmd.getSoapHeaders())
+ {
+ uhmd.addSoapHeader(soapHeader);
+ }
+ for (String soapRole : hmd.getSoapRoles())
+ {
+ uhmd.addSoapRole(soapRole);
+ }
+ handlers.add(uhmd);
+ }
+ usrmd.setHandlers(handlers);
+
+ usrmd.setConfigName(srmd.getConfigName());
+ usrmd.setConfigFile(srmd.getConfigFile());
+ usrmd.setWsdlOverride(srmd.getWsdlOverride());
+ usrmd.setCallProperties(srmd.getCallProperties());
+
+ return usrmd;
+ }
+}
Deleted: trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployer.java
===================================================================
--- branches/jbossws-1.2.0/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployer.java 2007-02-23 20:32:50 UTC (rev 2460)
+++ trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployer.java 2007-02-23 20:33:41 UTC (rev 2461)
@@ -1,140 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source
- * Copyright 2005, JBoss Inc., and individual contributors as indicated
- * by the @authors tag. See the copyright.txt in the distribution for a
- * full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
- */
-package org.jboss.ws.integration.jboss40;
-
-// $Id$
-
-import java.net.URL;
-import java.util.Iterator;
-
-import javax.naming.Context;
-import javax.wsdl.Definition;
-import javax.wsdl.WSDLException;
-import javax.xml.rpc.JAXRPCException;
-
-import org.jboss.deployment.DeploymentException;
-import org.jboss.deployment.DeploymentInfo;
-import org.jboss.system.ServiceMBeanSupport;
-import org.jboss.util.naming.Util;
-import org.jboss.webservice.metadata.serviceref.ServiceRefMetaData;
-import org.jboss.ws.WSException;
-import org.jboss.ws.core.jaxrpc.client.ServiceReferenceable;
-import org.jboss.ws.core.server.UnifiedDeploymentInfo;
-import org.jboss.ws.integration.jboss42.DeploymentInfoAdaptor;
-import org.jboss.ws.metadata.builder.jaxrpc.JAXRPCClientDeployment;
-import org.jboss.ws.metadata.j2ee.UnifiedServiceRefMetaData;
-import org.jboss.ws.metadata.jaxrpcmapping.JavaWsdlMapping;
-import org.jboss.ws.metadata.jaxrpcmapping.JavaWsdlMappingFactory;
-import org.jboss.ws.tools.wsdl.WSDL11DefinitionFactory;
-
-/**
- * Binds a JAXRPC Service object in the client's ENC for every service-ref element in the
- * deployment descriptor.
- *
- * @author Thomas.Diesler(a)jboss.org
- * @since 15-Jan-2005
- */
-public class WebServiceClientDeployer extends ServiceMBeanSupport implements WebServiceClientDeployerMBean
-{
- /**
- * This binds a jaxrpc Service into the callers ENC for every service-ref element
- *
- * @param envCtx ENC to bind the javax.rpc.xml.Service object to
- * @param serviceRefs An iterator of the service-ref elements in the client deployment descriptor
- * @param di The client's deployment info
- * @throws org.jboss.deployment.DeploymentException if it goes wrong
- */
- public void setupServiceRefEnvironment(Context envCtx, Iterator serviceRefs, DeploymentInfo di) throws DeploymentException
- {
- try
- {
- while (serviceRefs.hasNext())
- {
- ServiceRefMetaData serviceRef = (ServiceRefMetaData)serviceRefs.next();
- String serviceRefName = serviceRef.getServiceRefName();
-
- // Build the container independent deployment info
- UnifiedDeploymentInfo udi = new JAXRPCClientDeployment(UnifiedDeploymentInfo.DeploymentType.JAXRPC_Client);
- DeploymentInfoAdaptor.buildDeploymentInfo(udi, di);
-
- UnifiedServiceRefMetaData wsServiceRef = ServiceRefMetaDataAdaptor.buildUnifiedServiceRefMetaData(udi, serviceRef);
-
- JavaWsdlMapping javaWsdlMapping = getJavaWsdlMapping(wsServiceRef);
- wsServiceRef.setJavaWsdlMapping(javaWsdlMapping);
-
- Definition wsdlDefinition = getWsdlDefinition(wsServiceRef);
- wsServiceRef.setWsdlDefinition(wsdlDefinition);
-
- ServiceReferenceable ref = new ServiceReferenceable(wsServiceRef, udi);
- Util.bind(envCtx, serviceRefName, ref);
-
- log.debug("Webservice binding: java:comp/env/" + serviceRefName);
- }
- }
- catch (Exception e)
- {
- throw new DeploymentException("Cannot bind webservice to client environment", e);
- }
- }
-
- private JavaWsdlMapping getJavaWsdlMapping(UnifiedServiceRefMetaData serviceRef)
- {
- JavaWsdlMapping javaWsdlMapping = null;
- URL mappingURL = serviceRef.getMappingLocation();
- if (mappingURL != null)
- {
- try
- {
- // setup the XML binding Unmarshaller
- JavaWsdlMappingFactory mappingFactory = JavaWsdlMappingFactory.newInstance();
- javaWsdlMapping = mappingFactory.parse(mappingURL);
- }
- catch (Exception e)
- {
- throw new JAXRPCException("Cannot unmarshal jaxrpc-mapping-file: " + mappingURL, e);
- }
- }
- return javaWsdlMapping;
- }
-
- private Definition getWsdlDefinition(UnifiedServiceRefMetaData serviceRef)
- {
- Definition wsdlDefinition = null;
- {
- URL wsdlOverride = serviceRef.getWsdlOverride();
- URL wsdlURL = serviceRef.getWsdlLocation();
- if (wsdlOverride == null && wsdlURL != null)
- {
- try
- {
- WSDL11DefinitionFactory factory = WSDL11DefinitionFactory.newInstance();
- wsdlDefinition = factory.parse(wsdlURL);
- }
- catch (WSDLException e)
- {
- throw new WSException("Cannot unmarshall wsdl, cause: " + e.toString());
- }
- }
- }
- return wsdlDefinition;
- }
-}
Copied: trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployer.java (from rev 2460, branches/jbossws-1.2.0/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployer.java)
===================================================================
--- trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployer.java (rev 0)
+++ trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployer.java 2007-02-23 20:33:41 UTC (rev 2461)
@@ -0,0 +1,140 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2005, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.ws.integration.jboss40;
+
+// $Id$
+
+import java.net.URL;
+import java.util.Iterator;
+
+import javax.naming.Context;
+import javax.wsdl.Definition;
+import javax.wsdl.WSDLException;
+import javax.xml.rpc.JAXRPCException;
+
+import org.jboss.deployment.DeploymentException;
+import org.jboss.deployment.DeploymentInfo;
+import org.jboss.system.ServiceMBeanSupport;
+import org.jboss.util.naming.Util;
+import org.jboss.webservice.metadata.serviceref.ServiceRefMetaData;
+import org.jboss.ws.WSException;
+import org.jboss.ws.core.jaxrpc.client.ServiceReferenceable;
+import org.jboss.ws.core.server.UnifiedDeploymentInfo;
+import org.jboss.ws.integration.jboss42.DeploymentInfoAdaptor;
+import org.jboss.ws.metadata.builder.jaxrpc.JAXRPCClientDeployment;
+import org.jboss.ws.metadata.j2ee.UnifiedServiceRefMetaData;
+import org.jboss.ws.metadata.jaxrpcmapping.JavaWsdlMapping;
+import org.jboss.ws.metadata.jaxrpcmapping.JavaWsdlMappingFactory;
+import org.jboss.ws.tools.wsdl.WSDL11DefinitionFactory;
+
+/**
+ * Binds a JAXRPC Service object in the client's ENC for every service-ref element in the
+ * deployment descriptor.
+ *
+ * @author Thomas.Diesler(a)jboss.org
+ * @since 15-Jan-2005
+ */
+public class WebServiceClientDeployer extends ServiceMBeanSupport implements WebServiceClientDeployerMBean
+{
+ /**
+ * This binds a jaxrpc Service into the callers ENC for every service-ref element
+ *
+ * @param envCtx ENC to bind the javax.rpc.xml.Service object to
+ * @param serviceRefs An iterator of the service-ref elements in the client deployment descriptor
+ * @param di The client's deployment info
+ * @throws org.jboss.deployment.DeploymentException if it goes wrong
+ */
+ public void setupServiceRefEnvironment(Context envCtx, Iterator serviceRefs, DeploymentInfo di) throws DeploymentException
+ {
+ try
+ {
+ while (serviceRefs.hasNext())
+ {
+ ServiceRefMetaData serviceRef = (ServiceRefMetaData)serviceRefs.next();
+ String serviceRefName = serviceRef.getServiceRefName();
+
+ // Build the container independent deployment info
+ UnifiedDeploymentInfo udi = new JAXRPCClientDeployment(UnifiedDeploymentInfo.DeploymentType.JAXRPC_Client);
+ DeploymentInfoAdaptor.buildDeploymentInfo(udi, di);
+
+ UnifiedServiceRefMetaData wsServiceRef = ServiceRefMetaDataAdaptor.buildUnifiedServiceRefMetaData(udi, serviceRef);
+
+ JavaWsdlMapping javaWsdlMapping = getJavaWsdlMapping(wsServiceRef);
+ wsServiceRef.setJavaWsdlMapping(javaWsdlMapping);
+
+ Definition wsdlDefinition = getWsdlDefinition(wsServiceRef);
+ wsServiceRef.setWsdlDefinition(wsdlDefinition);
+
+ ServiceReferenceable ref = new ServiceReferenceable(wsServiceRef, udi);
+ Util.bind(envCtx, serviceRefName, ref);
+
+ log.debug("Webservice binding: java:comp/env/" + serviceRefName);
+ }
+ }
+ catch (Exception e)
+ {
+ throw new DeploymentException("Cannot bind webservice to client environment", e);
+ }
+ }
+
+ private JavaWsdlMapping getJavaWsdlMapping(UnifiedServiceRefMetaData serviceRef)
+ {
+ JavaWsdlMapping javaWsdlMapping = null;
+ URL mappingURL = serviceRef.getMappingLocation();
+ if (mappingURL != null)
+ {
+ try
+ {
+ // setup the XML binding Unmarshaller
+ JavaWsdlMappingFactory mappingFactory = JavaWsdlMappingFactory.newInstance();
+ javaWsdlMapping = mappingFactory.parse(mappingURL);
+ }
+ catch (Exception e)
+ {
+ throw new JAXRPCException("Cannot unmarshal jaxrpc-mapping-file: " + mappingURL, e);
+ }
+ }
+ return javaWsdlMapping;
+ }
+
+ private Definition getWsdlDefinition(UnifiedServiceRefMetaData serviceRef)
+ {
+ Definition wsdlDefinition = null;
+ {
+ URL wsdlOverride = serviceRef.getWsdlOverride();
+ URL wsdlURL = serviceRef.getWsdlLocation();
+ if (wsdlOverride == null && wsdlURL != null)
+ {
+ try
+ {
+ WSDL11DefinitionFactory factory = WSDL11DefinitionFactory.newInstance();
+ wsdlDefinition = factory.parse(wsdlURL);
+ }
+ catch (WSDLException e)
+ {
+ throw new WSException("Cannot unmarshall wsdl, cause: " + e.toString());
+ }
+ }
+ }
+ return wsdlDefinition;
+ }
+}
Deleted: trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployerMBean.java
===================================================================
--- branches/jbossws-1.2.0/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployerMBean.java 2007-02-23 20:32:50 UTC (rev 2460)
+++ trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployerMBean.java 2007-02-23 20:33:41 UTC (rev 2461)
@@ -1,38 +0,0 @@
-/*
-* JBoss, Home of Professional Open Source
-* Copyright 2005, JBoss Inc., and individual contributors as indicated
-* by the @authors tag. See the copyright.txt in the distribution for a
-* full listing of individual contributors.
-*
-* This is free software; you can redistribute it and/or modify it
-* under the terms of the GNU Lesser General Public License as
-* published by the Free Software Foundation; either version 2.1 of
-* the License, or (at your option) any later version.
-*
-* This software is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* Lesser General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public
-* License along with this software; if not, write to the Free
-* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-*/
-package org.jboss.ws.integration.jboss40;
-
-import javax.management.ObjectName;
-
-import org.jboss.system.ServiceMBean;
-import org.jboss.webservice.WebServiceClientDeployment;
-import org.jboss.ws.core.utils.ObjectNameFactory;
-
-/**
- * MBean interface.
- * @since 19-Jan-2005
- */
-public interface WebServiceClientDeployerMBean extends WebServiceClientDeployment, ServiceMBean
-{
- // default object name
- public static final ObjectName OBJECT_NAME = ObjectNameFactory.create("jboss.ws:service=WebServiceClientDeployer");
-}
Copied: trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployerMBean.java (from rev 2460, branches/jbossws-1.2.0/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployerMBean.java)
===================================================================
--- trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployerMBean.java (rev 0)
+++ trunk/integration-jboss40/src/main/java/org/jboss/ws/integration/jboss40/WebServiceClientDeployerMBean.java 2007-02-23 20:33:41 UTC (rev 2461)
@@ -0,0 +1,38 @@
+/*
+* JBoss, Home of Professional Open Source
+* Copyright 2005, JBoss Inc., and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+package org.jboss.ws.integration.jboss40;
+
+import javax.management.ObjectName;
+
+import org.jboss.system.ServiceMBean;
+import org.jboss.webservice.WebServiceClientDeployment;
+import org.jboss.ws.core.utils.ObjectNameFactory;
+
+/**
+ * MBean interface.
+ * @since 19-Jan-2005
+ */
+public interface WebServiceClientDeployerMBean extends WebServiceClientDeployment, ServiceMBean
+{
+ // default object name
+ public static final ObjectName OBJECT_NAME = ObjectNameFactory.create("jboss.ws:service=WebServiceClientDeployer");
+}
Copied: trunk/integration-jboss40/src/main/resources/jbossws.sar (from rev 2460, branches/jbossws-1.2.0/integration-jboss40/src/main/resources/jbossws.sar)
Copied: trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF (from rev 2460, branches/jbossws-1.2.0/integration-jboss40/src/main/resources/jbossws.sar/META-INF)
Deleted: trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml
===================================================================
--- branches/jbossws-1.2.0/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml 2007-02-23 20:32:50 UTC (rev 2460)
+++ trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml 2007-02-23 20:33:41 UTC (rev 2461)
@@ -1,49 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-
-<!-- $Id$ -->
-
-<server>
-
- <!--
- Bind JAXRPC ServiceRefs
- -->
- <mbean name="jboss.ws:service=WebServiceClientDeployer" code="org.jboss.ws.integration.jboss40.WebServiceClientDeployer">
- <depends>jboss:service=Naming</depends>
- </mbean>
-
- <!--
- A deployer service for JSE endpoints.
- -->
- <mbean name="jboss.ws:service=WebServiceDeployerJSE" code="org.jboss.ws.integration.jboss42.DeployerInterceptorJSE">
- <depends-list optional-attribute-name="Interceptables">
- <depends-list-element>jboss.web:service=WebServer</depends-list-element>
- </depends-list>
- </mbean>
-
- <!--
- A deployer service for EJB2.1 endpoints.
- -->
- <mbean name="jboss.ws:service=DeployerInterceptorEJB21" code="org.jboss.ws.integration.jboss42.DeployerInterceptorEJB21">
- <depends-list optional-attribute-name="Interceptables">
- <depends-list-element>jboss.ejb:service=EJBDeployer</depends-list-element>
- </depends-list>
- </mbean>
-
- <!--
- A deployer service for EJB3 endpoints.
- <mbean name="jboss.ws:service=DeployerInterceptorEJB3" code="org.jboss.ws.integration.jboss42.DeployerInterceptorEJB3">
- <depends-list optional-attribute-name="Interceptables">
- <depends-list-element>jboss.ejb3:service=EJB3Deployer</depends-list-element>
- </depends-list>
- </mbean>
- -->
-
- <!--
- A deployer service for JSE endpoints that are nested in service archives (sar).
- -->
- <mbean name="jboss.ws:service=DeployerInterceptorNestedJSE" code="org.jboss.ws.integration.jboss42.DeployerInterceptorNestedJSE">
- <depends optional-attribute-name="MainDeployer" proxy-type="attribute">jboss.system:service=MainDeployer</depends>
- <depends>jboss.ws:service=WebServiceDeployerJSE</depends>
- </mbean>
-
-</server>
Copied: trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml (from rev 2460, branches/jbossws-1.2.0/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml)
===================================================================
--- trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml (rev 0)
+++ trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml 2007-02-23 20:33:41 UTC (rev 2461)
@@ -0,0 +1,49 @@
+<?xml version="1.0" encoding="UTF-8"?>
+
+<!-- $Id$ -->
+
+<server>
+
+ <!--
+ Bind JAXRPC ServiceRefs
+ -->
+ <mbean name="jboss.ws:service=WebServiceClientDeployer" code="org.jboss.ws.integration.jboss40.WebServiceClientDeployer">
+ <depends>jboss:service=Naming</depends>
+ </mbean>
+
+ <!--
+ A deployer service for JSE endpoints.
+ -->
+ <mbean name="jboss.ws:service=WebServiceDeployerJSE" code="org.jboss.ws.integration.jboss42.DeployerInterceptorJSE">
+ <depends-list optional-attribute-name="Interceptables">
+ <depends-list-element>jboss.web:service=WebServer</depends-list-element>
+ </depends-list>
+ </mbean>
+
+ <!--
+ A deployer service for EJB2.1 endpoints.
+ -->
+ <mbean name="jboss.ws:service=DeployerInterceptorEJB21" code="org.jboss.ws.integration.jboss42.DeployerInterceptorEJB21">
+ <depends-list optional-attribute-name="Interceptables">
+ <depends-list-element>jboss.ejb:service=EJBDeployer</depends-list-element>
+ </depends-list>
+ </mbean>
+
+ <!--
+ A deployer service for EJB3 endpoints.
+ <mbean name="jboss.ws:service=DeployerInterceptorEJB3" code="org.jboss.ws.integration.jboss42.DeployerInterceptorEJB3">
+ <depends-list optional-attribute-name="Interceptables">
+ <depends-list-element>jboss.ejb3:service=EJB3Deployer</depends-list-element>
+ </depends-list>
+ </mbean>
+ -->
+
+ <!--
+ A deployer service for JSE endpoints that are nested in service archives (sar).
+ -->
+ <mbean name="jboss.ws:service=DeployerInterceptorNestedJSE" code="org.jboss.ws.integration.jboss42.DeployerInterceptorNestedJSE">
+ <depends optional-attribute-name="MainDeployer" proxy-type="attribute">jboss.system:service=MainDeployer</depends>
+ <depends>jboss.ws:service=WebServiceDeployerJSE</depends>
+ </mbean>
+
+</server>
Deleted: trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service.xml
===================================================================
--- branches/jbossws-1.2.0/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service.xml 2007-02-23 20:32:50 UTC (rev 2460)
+++ trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service.xml 2007-02-23 20:33:41 UTC (rev 2461)
@@ -1,49 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-
-<!-- $Id$ -->
-
-<server>
-
- <!--
- Bind JAXRPC ServiceRefs
- -->
- <mbean name="jboss.ws:service=WebServiceClientDeployer" code="org.jboss.ws.integration.jboss40.WebServiceClientDeployer">
- <depends>jboss:service=Naming</depends>
- </mbean>
-
- <!--
- A deployer service for JSE endpoints.
- -->
- <mbean name="jboss.ws:service=WebServiceDeployerJSE" code="org.jboss.ws.integration.jboss42.DeployerInterceptorJSE">
- <depends-list optional-attribute-name="Interceptables">
- <depends-list-element>jboss.web:service=WebServer</depends-list-element>
- </depends-list>
- </mbean>
-
- <!--
- A deployer service for EJB2.1 endpoints.
- -->
- <mbean name="jboss.ws:service=DeployerInterceptorEJB21" code="org.jboss.ws.integration.jboss42.DeployerInterceptorEJB21">
- <depends-list optional-attribute-name="Interceptables">
- <depends-list-element>jboss.ejb:service=EJBDeployer</depends-list-element>
- </depends-list>
- </mbean>
-
- <!--
- A deployer service for EJB3 endpoints.
- -->
- <mbean name="jboss.ws:service=DeployerInterceptorEJB3" code="org.jboss.ws.integration.jboss42.DeployerInterceptorEJB3">
- <depends-list optional-attribute-name="Interceptables">
- <depends-list-element>jboss.ejb3:service=EJB3Deployer</depends-list-element>
- </depends-list>
- </mbean>
-
- <!--
- A deployer service for JSE endpoints that are nested in service archives (sar).
- -->
- <mbean name="jboss.ws:service=DeployerInterceptorNestedJSE" code="org.jboss.ws.integration.jboss42.DeployerInterceptorNestedJSE">
- <depends optional-attribute-name="MainDeployer" proxy-type="attribute">jboss.system:service=MainDeployer</depends>
- <depends>jboss.ws:service=WebServiceDeployerJSE</depends>
- </mbean>
-
-</server>
Copied: trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service.xml (from rev 2460, branches/jbossws-1.2.0/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service.xml)
===================================================================
--- trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service.xml (rev 0)
+++ trunk/integration-jboss40/src/main/resources/jbossws.sar/META-INF/jboss-service.xml 2007-02-23 20:33:41 UTC (rev 2461)
@@ -0,0 +1,49 @@
+<?xml version="1.0" encoding="UTF-8"?>
+
+<!-- $Id$ -->
+
+<server>
+
+ <!--
+ Bind JAXRPC ServiceRefs
+ -->
+ <mbean name="jboss.ws:service=WebServiceClientDeployer" code="org.jboss.ws.integration.jboss40.WebServiceClientDeployer">
+ <depends>jboss:service=Naming</depends>
+ </mbean>
+
+ <!--
+ A deployer service for JSE endpoints.
+ -->
+ <mbean name="jboss.ws:service=WebServiceDeployerJSE" code="org.jboss.ws.integration.jboss42.DeployerInterceptorJSE">
+ <depends-list optional-attribute-name="Interceptables">
+ <depends-list-element>jboss.web:service=WebServer</depends-list-element>
+ </depends-list>
+ </mbean>
+
+ <!--
+ A deployer service for EJB2.1 endpoints.
+ -->
+ <mbean name="jboss.ws:service=DeployerInterceptorEJB21" code="org.jboss.ws.integration.jboss42.DeployerInterceptorEJB21">
+ <depends-list optional-attribute-name="Interceptables">
+ <depends-list-element>jboss.ejb:service=EJBDeployer</depends-list-element>
+ </depends-list>
+ </mbean>
+
+ <!--
+ A deployer service for EJB3 endpoints.
+ -->
+ <mbean name="jboss.ws:service=DeployerInterceptorEJB3" code="org.jboss.ws.integration.jboss42.DeployerInterceptorEJB3">
+ <depends-list optional-attribute-name="Interceptables">
+ <depends-list-element>jboss.ejb3:service=EJB3Deployer</depends-list-element>
+ </depends-list>
+ </mbean>
+
+ <!--
+ A deployer service for JSE endpoints that are nested in service archives (sar).
+ -->
+ <mbean name="jboss.ws:service=DeployerInterceptorNestedJSE" code="org.jboss.ws.integration.jboss42.DeployerInterceptorNestedJSE">
+ <depends optional-attribute-name="MainDeployer" proxy-type="attribute">jboss.system:service=MainDeployer</depends>
+ <depends>jboss.ws:service=WebServiceDeployerJSE</depends>
+ </mbean>
+
+</server>
18 years
JBossWS SVN: r2460 - trunk/integration-jboss42/src/main/java/org/jboss/ws/integration/jboss42.
by jbossws-commits@lists.jboss.org
Author: jason.greene(a)jboss.com
Date: 2007-02-23 15:32:50 -0500 (Fri, 23 Feb 2007)
New Revision: 2460
Added:
trunk/integration-jboss42/src/main/java/org/jboss/ws/integration/jboss42/ServiceRefHandler.java
trunk/integration-jboss42/src/main/java/org/jboss/ws/integration/jboss42/ServiceRefHandlerMBean.java
Log:
merge missing jboss42 integration
Copied: trunk/integration-jboss42/src/main/java/org/jboss/ws/integration/jboss42/ServiceRefHandler.java (from rev 2459, branches/jbossws-1.2.0/integration-jboss42/src/main/java/org/jboss/ws/integration/jboss42/ServiceRefHandler.java)
===================================================================
--- trunk/integration-jboss42/src/main/java/org/jboss/ws/integration/jboss42/ServiceRefHandler.java (rev 0)
+++ trunk/integration-jboss42/src/main/java/org/jboss/ws/integration/jboss42/ServiceRefHandler.java 2007-02-23 20:32:50 UTC (rev 2460)
@@ -0,0 +1,139 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2005, JBoss Inc., and individual contributors as indicated
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.ws.integration.jboss42;
+
+// $Id$
+
+import java.net.URL;
+import java.util.Iterator;
+
+import javax.naming.Context;
+import javax.wsdl.Definition;
+import javax.wsdl.WSDLException;
+import javax.xml.rpc.JAXRPCException;
+
+import org.jboss.deployment.DeploymentException;
+import org.jboss.deployment.DeploymentInfo;
+import org.jboss.metadata.serviceref.ServiceRefMetaData;
+import org.jboss.system.ServiceMBeanSupport;
+import org.jboss.util.naming.Util;
+import org.jboss.ws.WSException;
+import org.jboss.ws.core.jaxrpc.client.ServiceReferenceable;
+import org.jboss.ws.core.server.UnifiedDeploymentInfo;
+import org.jboss.ws.metadata.builder.jaxrpc.JAXRPCClientDeployment;
+import org.jboss.ws.metadata.j2ee.UnifiedServiceRefMetaData;
+import org.jboss.ws.metadata.jaxrpcmapping.JavaWsdlMapping;
+import org.jboss.ws.metadata.jaxrpcmapping.JavaWsdlMappingFactory;
+import org.jboss.ws.tools.wsdl.WSDL11DefinitionFactory;
+
+/**
+ * Binds a JAXRPC Service object in the client's ENC for every service-ref element in the
+ * deployment descriptor.
+ *
+ * @author Thomas.Diesler(a)jboss.org
+ * @since 15-Jan-2005
+ */
+public class ServiceRefHandler extends ServiceMBeanSupport implements ServiceRefHandlerMBean
+{
+ /**
+ * This binds a jaxrpc Service into the callers ENC for every service-ref element
+ *
+ * @param envCtx ENC to bind the javax.rpc.xml.Service object to
+ * @param serviceRefs An iterator of the service-ref elements in the client deployment descriptor
+ * @param di The client's deployment info
+ * @throws org.jboss.deployment.DeploymentException if it goes wrong
+ */
+ public void bindServiceRefs(Context envCtx, Iterator serviceRefs, DeploymentInfo di) throws DeploymentException
+ {
+ try
+ {
+ while (serviceRefs.hasNext())
+ {
+ ServiceRefMetaData serviceRef = (ServiceRefMetaData)serviceRefs.next();
+ String serviceRefName = serviceRef.getServiceRefName();
+
+ // Build the container independent deployment info
+ UnifiedDeploymentInfo udi = new JAXRPCClientDeployment(UnifiedDeploymentInfo.DeploymentType.JAXRPC_Client);
+ DeploymentInfoAdaptor.buildDeploymentInfo(udi, di);
+
+ UnifiedServiceRefMetaData wsServiceRef = ServiceRefMetaDataAdaptor.buildUnifiedServiceRefMetaData(udi, serviceRef);
+
+ JavaWsdlMapping javaWsdlMapping = getJavaWsdlMapping(wsServiceRef);
+ wsServiceRef.setJavaWsdlMapping(javaWsdlMapping);
+
+ Definition wsdlDefinition = getWsdlDefinition(wsServiceRef);
+ wsServiceRef.setWsdlDefinition(wsdlDefinition);
+
+ ServiceReferenceable ref = new ServiceReferenceable(wsServiceRef, udi);
+ Util.bind(envCtx, serviceRefName, ref);
+
+ log.debug("Webservice binding: java:comp/env/" + serviceRefName);
+ }
+ }
+ catch (Exception e)
+ {
+ throw new DeploymentException("Cannot bind webservice to client environment", e);
+ }
+ }
+
+ private JavaWsdlMapping getJavaWsdlMapping(UnifiedServiceRefMetaData serviceRef)
+ {
+ JavaWsdlMapping javaWsdlMapping = null;
+ URL mappingURL = serviceRef.getMappingLocation();
+ if (mappingURL != null)
+ {
+ try
+ {
+ // setup the XML binding Unmarshaller
+ JavaWsdlMappingFactory mappingFactory = JavaWsdlMappingFactory.newInstance();
+ javaWsdlMapping = mappingFactory.parse(mappingURL);
+ }
+ catch (Exception e)
+ {
+ throw new JAXRPCException("Cannot unmarshal jaxrpc-mapping-file: " + mappingURL, e);
+ }
+ }
+ return javaWsdlMapping;
+ }
+
+ private Definition getWsdlDefinition(UnifiedServiceRefMetaData serviceRef)
+ {
+ Definition wsdlDefinition = null;
+ {
+ URL wsdlOverride = serviceRef.getWsdlOverride();
+ URL wsdlURL = serviceRef.getWsdlLocation();
+ if (wsdlOverride == null && wsdlURL != null)
+ {
+ try
+ {
+ WSDL11DefinitionFactory factory = WSDL11DefinitionFactory.newInstance();
+ wsdlDefinition = factory.parse(wsdlURL);
+ }
+ catch (WSDLException e)
+ {
+ throw new WSException("Cannot unmarshall wsdl, cause: " + e.toString());
+ }
+ }
+ }
+ return wsdlDefinition;
+ }
+}
Copied: trunk/integration-jboss42/src/main/java/org/jboss/ws/integration/jboss42/ServiceRefHandlerMBean.java (from rev 2459, branches/jbossws-1.2.0/integration-jboss42/src/main/java/org/jboss/ws/integration/jboss42/ServiceRefHandlerMBean.java)
===================================================================
--- trunk/integration-jboss42/src/main/java/org/jboss/ws/integration/jboss42/ServiceRefHandlerMBean.java (rev 0)
+++ trunk/integration-jboss42/src/main/java/org/jboss/ws/integration/jboss42/ServiceRefHandlerMBean.java 2007-02-23 20:32:50 UTC (rev 2460)
@@ -0,0 +1,38 @@
+/*
+* JBoss, Home of Professional Open Source
+* Copyright 2005, JBoss Inc., and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+package org.jboss.ws.integration.jboss42;
+
+import javax.management.ObjectName;
+
+import org.jboss.system.ServiceMBean;
+import org.jboss.metadata.serviceref.ServiceRefHandler;
+import org.jboss.ws.core.utils.ObjectNameFactory;
+
+/**
+ * MBean interface.
+ * @since 19-Jan-2005
+ */
+public interface ServiceRefHandlerMBean extends ServiceRefHandler, ServiceMBean
+{
+ // default object name
+ public static final ObjectName OBJECT_NAME = ObjectNameFactory.create("jboss.ws:service=ServiceRefHandler");
+}
18 years
JBossWS SVN: r2459 - in trunk/integration-jboss40: src/main/resources/jbossws.beans/META-INF and 1 other directory.
by jbossws-commits@lists.jboss.org
Author: jason.greene(a)jboss.com
Date: 2007-02-23 15:30:10 -0500 (Fri, 23 Feb 2007)
New Revision: 2459
Modified:
trunk/integration-jboss40/.classpath
trunk/integration-jboss40/build.xml
trunk/integration-jboss40/src/main/resources/jbossws.beans/META-INF/jboss-beans.xml
Log:
sync missing jboss40 changes
Modified: trunk/integration-jboss40/.classpath
===================================================================
--- trunk/integration-jboss40/.classpath 2007-02-23 20:27:37 UTC (rev 2458)
+++ trunk/integration-jboss40/.classpath 2007-02-23 20:30:10 UTC (rev 2459)
@@ -30,5 +30,6 @@
<classpathentry kind="lib" path="/build/thirdparty/xercesImpl.jar"/>
<classpathentry kind="lib" path="/build/thirdparty/mail.jar"/>
<classpathentry kind="lib" path="/build/thirdparty/jboss-common.jar" sourcepath="/build/thirdparty/jboss-common-sources.jar"/>
+ <classpathentry kind="con" path="org.eclipse.jdt.USER_LIBRARY/jboss-4.0.x"/>
<classpathentry kind="output" path="output-eclipse"/>
</classpath>
Modified: trunk/integration-jboss40/build.xml
===================================================================
--- trunk/integration-jboss40/build.xml 2007-02-23 20:27:37 UTC (rev 2458)
+++ trunk/integration-jboss40/build.xml 2007-02-23 20:30:10 UTC (rev 2459)
@@ -57,12 +57,17 @@
<!-- Compile integration java sources -->
<target name="jboss40-compile-classes" depends="jboss40-init,core-compile">
<mkdir dir="${jboss40.output.classes.dir}"/>
- <javac srcdir="${jboss42.java.dir}" sourcepath="" destdir="${jboss40.output.classes.dir}" encoding="utf-8" debug="${javac.debug}" verbose="${javac.verbose}"
+ <javac sourcepath="" destdir="${jboss40.output.classes.dir}" encoding="utf-8" debug="${javac.debug}" verbose="${javac.verbose}"
deprecation="${javac.deprecation}" failonerror="${javac.fail.onerror}">
+ <src location="${jboss42.java.dir}"/>
+ <src location="${jboss40.java.dir}"/>
+ <include name="org/jboss/ws/integration/jboss40/**"/>
<include name="org/jboss/ws/integration/jboss42/**"/>
<exclude name="org/jboss/ws/integration/jboss42/DeployerInterceptorEJB3.java"/>
<exclude name="org/jboss/ws/integration/jboss42/ServiceEndpointGeneratorEJB3.java"/>
<exclude name="org/jboss/ws/integration/jboss42/ServiceEndpointInvokerEJB3.java"/>
+ <exclude name="org/jboss/ws/integration/jboss42/ServiceRefHandlerMBean.java"/>
+ <exclude name="org/jboss/ws/integration/jboss42/ServiceRefHandler.java"/>
<classpath refid="jboss40.integration.classpath"/>
<classpath path="${core.output.classes14.dir}"/>
<classpath path="${core.output.classes.dir}"/>
@@ -70,8 +75,10 @@
</target>
<target name="jboss40-compile-ejb3-classes" depends="jboss40-init,core-compile,jboss40-check-ejb3-classes" if="jboss40.ejb3.available">
<mkdir dir="${jboss40.output.classes.dir}"/>
- <javac srcdir="${jboss42.java.dir}" sourcepath="" destdir="${jboss40.output.classes.dir}" encoding="utf-8" debug="${javac.debug}" verbose="${javac.verbose}"
+ <javac sourcepath="" destdir="${jboss40.output.classes.dir}" encoding="utf-8" debug="${javac.debug}" verbose="${javac.verbose}"
deprecation="${javac.deprecation}" failonerror="${javac.fail.onerror}">
+ <src location="${jboss42.java.dir}"/>
+ <src location="${jboss40.java.dir}"/>
<include name="org/jboss/ws/integration/jboss42/DeployerInterceptorEJB3.java"/>
<include name="org/jboss/ws/integration/jboss42/ServiceEndpointGeneratorEJB3.java"/>
<include name="org/jboss/ws/integration/jboss42/ServiceEndpointInvokerEJB3.java"/>
@@ -146,6 +153,7 @@
<jar jarfile="${jboss40.output.lib.dir}/jbossws-jboss40-integration.jar" manifest="${etc.dir}/default.mf">
<fileset dir="${jboss40.output.classes.dir}">
<include name="org/jboss/ws/integration/jboss42/**"/>
+ <include name="org/jboss/ws/integration/jboss40/**"/>
</fileset>
<metainf dir="${jboss42.resources.dir}/jbossws-jboss42-integration.jar/META-INF"/>
</jar>
@@ -188,7 +196,7 @@
<include name="standard-jaxws-client-config.xml"/>
<include name="standard-jaxws-endpoint-config.xml"/>
</metainf>
- <metainf dir="${jboss42.resources.dir}/jbossws.sar/META-INF">
+ <metainf dir="${jboss40.resources.dir}/jbossws.sar/META-INF">
<include name="jboss-service*.xml"/>
</metainf>
</jar>
@@ -225,6 +233,7 @@
<jar jarfile="${jboss40.output.lib.dir}/jbossws14-jboss40-integration.jar" manifest="${etc.dir}/default.mf">
<fileset dir="${jboss40.output.classes14.dir}">
<include name="org/jboss/ws/integration/jboss42/**"/>
+ <include name="org/jboss/ws/integration/jboss40/**"/>
</fileset>
<metainf dir="${jboss42.resources.dir}/jbossws-jboss42-integration.jar/META-INF"/>
</jar>
@@ -258,7 +267,7 @@
<mkdir dir="${jboss40.output.dir}/resources/jbossws40-jdk14.sar/META-INF"/>
<copy tofile="${jboss40.output.dir}/resources/jbossws40-jdk14.sar/META-INF/jboss-service.xml"
- file="${jboss42.resources.dir}/jbossws.sar/META-INF/jboss-service-no-ejb3.xml"/>
+ file="${jboss40.resources.dir}/jbossws.sar/META-INF/jboss-service-no-ejb3.xml"/>
<!-- Build jbossws40-jdk14.sar -->
<jar jarfile="${jboss40.output.lib.dir}/jbossws40-jdk14.sar" manifest="${etc.dir}/default.mf">
@@ -295,6 +304,12 @@
<!-- Deploy jbossws to jboss40 -->
<target name="deploy-jboss40" depends="jboss40-jars" description="Deploy jbossws">
+ <copy todir="${jboss40.home}/bin" overwrite="true">
+ <fileset dir="${etc.dir}">
+ <include name="*.bat"/>
+ <include name="*.sh"/>
+ </fileset>
+ </copy>
<delete file="${jboss40.home}/client/jbossws14-client.jar"/>
<copy todir="${jboss40.home}/client" overwrite="true">
<fileset dir="${core.output.lib.dir}">
@@ -303,9 +318,11 @@
<include name="jboss-saaj.jar"/>
<include name="jbossws-client.jar"/>
</fileset>
+ <!-- Only available on jdk1.5 -->
<fileset dir="${thirdparty.dir}">
<include name="jaxb-api.jar"/>
<include name="jaxb-impl.jar"/>
+ <include name="jaxb-xjc.jar"/>
<include name="jbossws-wsconsume-impl.jar"/>
</fileset>
</copy>
@@ -345,8 +362,13 @@
<!-- Deploy jbossws to jboss40 jdk1.4 -->
<target name="deploy-jboss40-jdk14" depends="jboss40-jars14" description="Deploy jbossws">
+ <copy todir="${jboss40.home}/bin" overwrite="true">
+ <fileset dir="${etc.dir}">
+ <include name="*.bat"/>
+ <include name="*.sh"/>
+ </fileset>
+ </copy>
<delete file="${jboss40.home}/client/jbossws-client.jar"/>
- <delete file="${jboss40.home}/server/${jboss.server.instance}/lib/jboss-jaxws.jar"/>
<copy todir="${jboss40.home}/client" overwrite="true">
<fileset dir="${core.output.lib.dir}">
<include name="jboss-jaxrpc.jar"/>
@@ -355,11 +377,8 @@
<fileset dir="${jboss40.output.lib.dir}">
<include name="jbossws14-client.jar"/>
</fileset>
- <fileset dir="${thirdparty.dir}">
- <include name="jaxb-api.jar"/>
- <include name="jaxb-impl.jar"/>
- </fileset>
</copy>
+ <delete file="${jboss40.home}/server/${jboss.server.instance}/lib/jboss-jaxws.jar"/>
<copy todir="${jboss40.home}/server/${jboss.server.instance}/lib" overwrite="true">
<fileset dir="${core.output.lib.dir}">
<include name="jboss-jaxrpc.jar"/>
Modified: trunk/integration-jboss40/src/main/resources/jbossws.beans/META-INF/jboss-beans.xml
===================================================================
--- trunk/integration-jboss40/src/main/resources/jbossws.beans/META-INF/jboss-beans.xml 2007-02-23 20:27:37 UTC (rev 2458)
+++ trunk/integration-jboss40/src/main/resources/jbossws.beans/META-INF/jboss-beans.xml 2007-02-23 20:30:10 UTC (rev 2459)
@@ -46,12 +46,6 @@
<property name="serviceEndpointServlet">org.jboss.ws.integration.jboss42.JBossServiceEndpointServlet</property>
</bean>
- <!--
- Bind JAXWS Service objects in client environment context
- JAX-WS functionality is not available with jdk-1.4
- <bean name="WebServiceRefHandler" class="org.jboss.ws.integration.jboss42.WebServiceRefHandler"/>
- -->
-
<!-- A subscription manager for WS-Eventing -->
<bean name="SubscriptionManager" class="org.jboss.ws.extensions.eventing.mgmt.SubscriptionManager"/>
18 years
JBossWS SVN: r2458 - in trunk/integration-jboss42: src/main/resources/jbossws.sar/META-INF and 1 other directory.
by jbossws-commits@lists.jboss.org
Author: jason.greene(a)jboss.com
Date: 2007-02-23 15:27:37 -0500 (Fri, 23 Feb 2007)
New Revision: 2458
Modified:
trunk/integration-jboss42/build.xml
trunk/integration-jboss42/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml
trunk/integration-jboss42/src/main/resources/jbossws.sar/META-INF/jboss-service.xml
Log:
sync missing jboss42 integration changes
Modified: trunk/integration-jboss42/build.xml
===================================================================
--- trunk/integration-jboss42/build.xml 2007-02-23 20:21:21 UTC (rev 2457)
+++ trunk/integration-jboss42/build.xml 2007-02-23 20:27:37 UTC (rev 2458)
@@ -157,6 +157,12 @@
<!-- Deploy jbossws to jboss42 -->
<target name="deploy-jboss42" depends="jboss42-jars" description="Deploy jbossws">
+ <copy todir="${jboss42.home}/bin" overwrite="true">
+ <fileset dir="${etc.dir}">
+ <include name="*.bat"/>
+ <include name="*.sh"/>
+ </fileset>
+ </copy>
<copy todir="${jboss42.home}/client" overwrite="true">
<fileset dir="${core.output.lib.dir}">
<include name="jboss-jaxrpc.jar"/>
@@ -164,9 +170,10 @@
<include name="jboss-saaj.jar"/>
<include name="jbossws-client.jar"/>
</fileset>
- </copy>
- <copy todir="${jboss50.home}/client" overwrite="true">
<fileset dir="${thirdparty.dir}">
+ <include name="jaxb-api.jar"/>
+ <include name="jaxb-impl.jar"/>
+ <include name="jaxb-xjc.jar"/>
<include name="jbossws-wsconsume-impl.jar"/>
</fileset>
</copy>
Modified: trunk/integration-jboss42/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml
===================================================================
--- trunk/integration-jboss42/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml 2007-02-23 20:21:21 UTC (rev 2457)
+++ trunk/integration-jboss42/src/main/resources/jbossws.sar/META-INF/jboss-service-no-ejb3.xml 2007-02-23 20:27:37 UTC (rev 2458)
@@ -5,9 +5,9 @@
<server>
<!--
- A deployer service for WS clients.
+ Bind JAXRPC ServiceRefs
-->
- <mbean name="jboss.ws:service=WebServiceClientDeployer" code="org.jboss.ws.integration.jboss42.WebServiceClientDeployer">
+ <mbean name="jboss.ws:service=ServiceRefHandler" code="org.jboss.ws.integration.jboss42.ServiceRefHandler">
<depends>jboss:service=Naming</depends>
</mbean>
Modified: trunk/integration-jboss42/src/main/resources/jbossws.sar/META-INF/jboss-service.xml
===================================================================
--- trunk/integration-jboss42/src/main/resources/jbossws.sar/META-INF/jboss-service.xml 2007-02-23 20:21:21 UTC (rev 2457)
+++ trunk/integration-jboss42/src/main/resources/jbossws.sar/META-INF/jboss-service.xml 2007-02-23 20:27:37 UTC (rev 2458)
@@ -5,9 +5,9 @@
<server>
<!--
- A deployer service for WS clients.
+ Bind JAXRPC ServiceRefs
-->
- <mbean name="jboss.ws:service=WebServiceClientDeployer" code="org.jboss.ws.integration.jboss42.WebServiceClientDeployer">
+ <mbean name="jboss.ws:service=ServiceRefHandler" code="org.jboss.ws.integration.jboss42.ServiceRefHandler">
<depends>jboss:service=Naming</depends>
</mbean>
18 years
JBossWS SVN: r2457 - in trunk/jbossws-core: src/main/java/org/jboss/ws/core and 6 other directories.
by jbossws-commits@lists.jboss.org
Author: jason.greene(a)jboss.com
Date: 2007-02-23 15:21:21 -0500 (Fri, 23 Feb 2007)
New Revision: 2457
Modified:
trunk/jbossws-core/build.xml
trunk/jbossws-core/src/main/java/org/jboss/ws/core/CommonContextServlet.java
trunk/jbossws-core/src/main/java/org/jboss/ws/core/jaxrpc/TypeMappingImpl.java
trunk/jbossws-core/src/main/java/org/jboss/ws/core/server/ServiceEndpointManager.java
trunk/jbossws-core/src/main/java/org/jboss/ws/tools/JavaToXSD.java
trunk/jbossws-core/src/main/java/org/jboss/ws/tools/helpers/MappingFileGeneratorHelper.java
trunk/jbossws-core/src/main/java/org/jboss/ws/tools/jaxws/command/wsprovide.java
trunk/jbossws-core/src/main/resources/jbossws.war/index.html
Log:
Merge all changes missing from trunk
Modified: trunk/jbossws-core/build.xml
===================================================================
--- trunk/jbossws-core/build.xml 2007-02-23 20:20:22 UTC (rev 2456)
+++ trunk/jbossws-core/build.xml 2007-02-23 20:21:21 UTC (rev 2457)
@@ -164,8 +164,8 @@
</fileset>
<zipfileset dir="${etc.dir}" filemode="755">
<include name="wsprovide.sh"/>
+ <include name="wsconsume.sh"/>
<include name="wsrunclient.sh"/>
- <include name="wsconsume.sh"/>
<include name="wstools.sh"/>
</zipfileset>
</jar>
Modified: trunk/jbossws-core/src/main/java/org/jboss/ws/core/CommonContextServlet.java
===================================================================
--- trunk/jbossws-core/src/main/java/org/jboss/ws/core/CommonContextServlet.java 2007-02-23 20:20:22 UTC (rev 2456)
+++ trunk/jbossws-core/src/main/java/org/jboss/ws/core/CommonContextServlet.java 2007-02-23 20:21:21 UTC (rev 2457)
@@ -85,7 +85,7 @@
if(endpoints.isEmpty())
{
writer.print("<tr>");
- writer.print(" <td><h3>There currently no endpoints deployed</h3></td>");
+ writer.print(" <td><h3>There are currently no endpoints deployed</h3></td>");
writer.print("</tr>");
}
Modified: trunk/jbossws-core/src/main/java/org/jboss/ws/core/jaxrpc/TypeMappingImpl.java
===================================================================
--- trunk/jbossws-core/src/main/java/org/jboss/ws/core/jaxrpc/TypeMappingImpl.java 2007-02-23 20:20:22 UTC (rev 2456)
+++ trunk/jbossws-core/src/main/java/org/jboss/ws/core/jaxrpc/TypeMappingImpl.java 2007-02-23 20:21:21 UTC (rev 2457)
@@ -124,6 +124,7 @@
{
if (log.isTraceEnabled())
log.trace("register: TypeMappingImpl@" + hashCode() + " [xmlType=" + xmlType + ",javaType=" + javaType.getName() + ",sf=" + sf + ",df=" + df + "]");
+
registerInternal(javaType, new IQName(xmlType), sf, df);
keyPairCache.clear();
}
Modified: trunk/jbossws-core/src/main/java/org/jboss/ws/core/server/ServiceEndpointManager.java
===================================================================
--- trunk/jbossws-core/src/main/java/org/jboss/ws/core/server/ServiceEndpointManager.java 2007-02-23 20:20:22 UTC (rev 2456)
+++ trunk/jbossws-core/src/main/java/org/jboss/ws/core/server/ServiceEndpointManager.java 2007-02-23 20:21:21 UTC (rev 2457)
@@ -32,9 +32,9 @@
import java.io.StringWriter;
import java.lang.reflect.Constructor;
import java.net.InetAddress;
-import java.net.MalformedURLException;
import java.net.URL;
import java.net.UnknownHostException;
+import java.net.MalformedURLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
Modified: trunk/jbossws-core/src/main/java/org/jboss/ws/tools/JavaToXSD.java
===================================================================
--- trunk/jbossws-core/src/main/java/org/jboss/ws/tools/JavaToXSD.java 2007-02-23 20:20:22 UTC (rev 2456)
+++ trunk/jbossws-core/src/main/java/org/jboss/ws/tools/JavaToXSD.java 2007-02-23 20:21:21 UTC (rev 2457)
@@ -170,6 +170,7 @@
URL orgURL = locs.get(nsURI);
URL resURL = resolveNamespaceURI(resolver, nsURI);
URL url = resURL != null ? resURL : orgURL;
+
log.debug("Load schema: " + nsURI + "=" + url);
XMLInputSource inputSource = new XMLInputSource(null, url.toExternalForm(), null);
Modified: trunk/jbossws-core/src/main/java/org/jboss/ws/tools/helpers/MappingFileGeneratorHelper.java
===================================================================
--- trunk/jbossws-core/src/main/java/org/jboss/ws/tools/helpers/MappingFileGeneratorHelper.java 2007-02-23 20:20:22 UTC (rev 2456)
+++ trunk/jbossws-core/src/main/java/org/jboss/ws/tools/helpers/MappingFileGeneratorHelper.java 2007-02-23 20:21:21 UTC (rev 2457)
@@ -533,58 +533,6 @@
return true;
}
- private void unwrapResponse(ServiceEndpointMethodMapping methodMapping, QName messageName, XSTypeDefinition xt)
- {
- if (xt instanceof XSComplexTypeDefinition == false)
- throw new WSException("Tried to unwrap a non-complex type.");
-
- XSComplexTypeDefinition wrapper = (XSComplexTypeDefinition)xt;
- XSParticle particle = wrapper.getParticle();
- XSTerm term = particle.getTerm();
- if (term instanceof XSModelGroup == false)
- throw new WSException("Expected model group, could not unwrap");
- unwrapResponseParticles(methodMapping, messageName, (XSModelGroup)term);
- }
-
- private boolean unwrapResponseParticles(ServiceEndpointMethodMapping methodMapping, QName messageName, XSModelGroup group)
- {
- if (group.getCompositor() != XSModelGroup.COMPOSITOR_SEQUENCE)
- throw new WSException("Only a sequence type can be unwrapped.");
-
- XSObjectList particles = group.getParticles();
-
- for (int i = 0; i < particles.getLength(); i++)
- {
- XSParticle particle = (XSParticle)particles.item(i);
- XSTerm term = particle.getTerm();
- if (term instanceof XSModelGroup)
- {
- if (unwrapResponseParticles(methodMapping, messageName, (XSModelGroup)term))
- return true;
- }
- else if (term instanceof XSElementDeclaration)
- {
- XSElementDeclaration element = (XSElementDeclaration)term;
- QName xmlName = new QName(element.getNamespace(), element.getName());
- QName xmlType = new QName(element.getTypeDefinition().getNamespace(), element.getTypeDefinition().getName());
- boolean array = particle.getMaxOccursUnbounded() || particle.getMaxOccurs() > 1;
- boolean primitive = !(element.getNillable() || (particle.getMinOccurs() == 0 && particle.getMaxOccurs() == 1));
-
- String javaType = getJavaTypeAsString(xmlName, xmlType, array, primitive);
-
- WsdlReturnValueMapping wrvm = new WsdlReturnValueMapping(methodMapping);
- wrvm.setMethodReturnValue(javaType);
- wrvm.setWsdlMessage(new QName(messageName.getNamespaceURI(), messageName.getLocalPart(), WSToolsConstants.WSTOOLS_CONSTANT_MAPPING_WSDL_MESSAGE_NS));
- wrvm.setWsdlMessagePartName(xmlName.getLocalPart());
- methodMapping.setWsdlReturnValueMapping(wrvm);
-
- return true;
- }
- }
-
- return false;
- }
-
private void checkEssentials()
{
if (typeMapping == null)
Modified: trunk/jbossws-core/src/main/java/org/jboss/ws/tools/jaxws/command/wsprovide.java
===================================================================
--- trunk/jbossws-core/src/main/resources/jbossws.war/index.html 2007-02-23 20:20:22 UTC (rev 2456)
+++ trunk/jbossws-core/src/main/resources/jbossws.war/index.html 2007-02-23 20:21:21 UTC (rev 2457)
@@ -9,7 +9,7 @@
<div class="pageSection">
<h2>J2EE compatible web services</h2>
-After JBoss J2EE-1.4 certification in Jun/2004 we have decided to develop our own JAX-RPC 1.1 / JAX-WS compliant SOAP stack that fits better in the overall JBoss architecture and is generally more suiteable for the specific J2EE requirements for web services.
+JBossWS is a JAX-WS compliant web service stack developed to be part of JBoss' JavaEE5 offering.
</div>
<div class="pageSection">
@@ -60,4 +60,4 @@
</div>
</body>
-</html>
\ No newline at end of file
+</html>
18 years
JBossWS SVN: r2456 - in branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws: core/jaxws and 1 other directories.
by jbossws-commits@lists.jboss.org
Author: jason.greene(a)jboss.com
Date: 2007-02-23 15:20:22 -0500 (Fri, 23 Feb 2007)
New Revision: 2456
Modified:
branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxrpc/binding/SOAPArraySerializer.java
branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxws/JAXBSerializer.java
branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxws/WebServiceContextJSE.java
branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/extensions/security/WSSecurityDispatcher.java
Log:
Merge more missing logging changes
Modified: branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxrpc/binding/SOAPArraySerializer.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxrpc/binding/SOAPArraySerializer.java 2007-02-23 20:11:35 UTC (rev 2455)
+++ branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxrpc/binding/SOAPArraySerializer.java 2007-02-23 20:20:22 UTC (rev 2456)
@@ -61,7 +61,7 @@
*/
public Result serialize(QName xmlName, QName xmlType, Object value, SerializationContext serContext, NamedNodeMap attributes) throws BindingException
{
- log.debug("serialize: [xmlName=" + xmlName + ",xmlType=" + xmlType + ",valueType=" + value.getClass().getName() + "]");
+ if(log.isDebugEnabled()) log.debug("serialize: [xmlName=" + xmlName + ",xmlType=" + xmlType + ",valueType=" + value.getClass().getName() + "]");
try
{
ParameterMetaData paramMetaData = (ParameterMetaData)serContext.getProperty(ParameterMetaData.class.getName());
@@ -88,7 +88,7 @@
throw new WSException("Cannot obtain component xmlType for: " + compJavaType);
// Get the component type serializer factory
- log.debug("Get component serializer for: [javaType=" + compJavaType.getName() + ",xmlType=" + compXmlType + "]");
+ if(log.isDebugEnabled()) log.debug("Get component serializer for: [javaType=" + compJavaType.getName() + ",xmlType=" + compXmlType + "]");
SerializerFactoryBase compSerializerFactory = (SerializerFactoryBase)typeMapping.getSerializer(compJavaType, compXmlType);
if (compSerializerFactory == null)
{
@@ -134,7 +134,7 @@
}
buffer.append("</" + Constants.PREFIX_SOAP11_ENC + ":Array>");
- log.debug("serialized: " + buffer);
+ if(log.isDebugEnabled()) log.debug("serialized: " + buffer);
return stringToResult(buffer.toString());
}
catch (RuntimeException e)
Modified: branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxws/JAXBSerializer.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxws/JAXBSerializer.java 2007-02-23 20:11:35 UTC (rev 2455)
+++ branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxws/JAXBSerializer.java 2007-02-23 20:20:22 UTC (rev 2456)
@@ -65,7 +65,7 @@
@Override
public Result serialize(QName xmlName, QName xmlType, Object value, SerializationContext serContext, NamedNodeMap attributes) throws BindingException
{
- log.debug("serialize: [xmlName=" + xmlName + ",xmlType=" + xmlType + "]");
+ if(log.isDebugEnabled()) log.debug("serialize: [xmlName=" + xmlName + ",xmlType=" + xmlType + "]");
Result result = null;
try
@@ -76,7 +76,7 @@
JAXBContextCache contextCache = JAXBContextCache.getContextCache();
JAXBContext jaxbContext = contextCache.getInstance(javaType);
-
+
Marshaller marshaller = jaxbContext.createMarshaller();
marshaller.setProperty(Marshaller.JAXB_FRAGMENT, true);
@@ -87,7 +87,7 @@
result = new BufferedStreamResult();
marshaller.marshal(new JAXBElement(xmlName, javaType, value), result);
- log.debug("serialized: " + result);
+ if(log.isDebugEnabled()) log.debug("serialized: " + result);
}
catch (Exception ex)
{
Modified: branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxws/WebServiceContextJSE.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxws/WebServiceContextJSE.java 2007-02-23 20:11:35 UTC (rev 2455)
+++ branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxws/WebServiceContextJSE.java 2007-02-23 20:20:22 UTC (rev 2456)
@@ -28,7 +28,6 @@
import javax.servlet.http.HttpServletRequest;
import javax.xml.ws.handler.MessageContext;
-import org.jboss.logging.Logger;
import org.jboss.ws.core.jaxws.handler.MessageContextJAXWS;
/**
@@ -39,9 +38,6 @@
*/
public class WebServiceContextJSE extends AbstractWebServiceContext
{
- // provide logging
- private Logger log = Logger.getLogger(WebServiceContextJSE.class);
-
private HttpServletRequest httpRequest;
public WebServiceContextJSE(MessageContext messageContext)
Modified: branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/extensions/security/WSSecurityDispatcher.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/extensions/security/WSSecurityDispatcher.java 2007-02-23 20:11:35 UTC (rev 2455)
+++ branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/extensions/security/WSSecurityDispatcher.java 2007-02-23 20:20:22 UTC (rev 2456)
@@ -162,7 +162,7 @@
List<OperationDescription<RequireOperation>> operations = buildRequireOperations(config, operation, port);
decoder.verify(operations);
- log.debug("Verification is successful");
+ if(log.isDebugEnabled()) log.debug("Verification is successful");
decoder.complete();
}
@@ -170,7 +170,7 @@
{
if (e.isInternalError())
log.error("Internal error occured handling inbound message:", e);
- else log.debug("Returning error to sender: " + e.getMessage());
+ else if(log.isDebugEnabled()) log.debug("Returning error to sender: " + e.getMessage());
throw convertToFault(e);
}
@@ -235,6 +235,7 @@
Config operationConfig = getConfig(config, port, operation);
log.debug("WS-Security config: " + operationConfig);
+
// Nothing to process
if (operationConfig == null)
return;
@@ -284,7 +285,7 @@
if (operations.size() == 0)
return;
- log.debug("Encoding Message:\n" + DOMWriter.printNode(soapMessage.getSOAPPart(), true));
+ if(log.isDebugEnabled()) log.debug("Encoding Message:\n" + DOMWriter.printNode(soapMessage.getSOAPPart(), true));
try
{
@@ -297,7 +298,7 @@
{
if (e.isInternalError())
log.error("Internal error occured handling outbound message:", e);
- else log.debug("Returning error to sender: " + e.getMessage());
+ else if(log.isDebugEnabled()) log.debug("Returning error to sender: " + e.getMessage());
throw convertToFault(e);
}
18 years
--- trunk/jbossws-core/src/main/java/org/jboss/ws/tools/jaxws/command/wsprovide.java 2007-02-23 20:20:22 UTC (rev 2456)
+++ trunk/jbossws-core/src/main/java/org/jboss/ws/tools/jaxws/command/wsprovide.java 2007-02-23 20:21:21 UTC (rev 2457)
@@ -45,7 +45,7 @@
* -h, --help Show this help message
* -k, --keep Keep/Generate Java source
* -w, --wsdl Enable WSDL file generation
* -c, --classpath=<directory> The classpath that contains the endpoint
* -o, --output=<directory> The directory to put generated artifacts
* -r, --resource=<directory> The directory to put resource artifacts
* -s, --source=<directory> The directory to put Java source
@@ -214,7 +214,7 @@
out.println(" -h, --help Show this help message");
out.println(" -k, --keep Keep/Generate Java source");
out.println(" -w, --wsdl Enable WSDL file generation");
- out.println(" -c, --classpath=<directory> The classpath that contains the endpoint");
+ out.println(" -c. --classpath=<path> The classpath that contains the endpoint");
out.println(" -o, --output=<directory> The directory to put generated artifacts");
out.println(" -r, --resource=<directory> The directory to put resource artifacts");
out.println(" -s, --source=<directory> The directory to put Java source");
@@ -45,7 +45,7 @@
* -k, --keep Keep/Generate Java source
* -w, --wsdl Enable WSDL file generation
- * -c, --classpath=<directory> The classpath that contains the endpoint
+ * -c. --classpath=<path< The classpath that contains the endpoint
* -o, --output=<directory> The directory to put generated artifacts
* -r, --resource=<directory> The directory to put resource artifacts
Modified: trunk/jbossws-core/src/main/resources/jbossws.war/index.html
===================================================================